@@ -40,19 +40,19 @@ require(matrixcalc)
 #'         Gaussian(s) (posterior probabilities, mean, co-variance/standard-deviation and priors)
 #'
 #'\enumerate{
-#'         \item [1] Posterior Probabilities: \strong{sample_out$prob}
+#'         \item (1) Posterior Probabilities: \strong{sample_out$prob}
 #'         A matrix of posterior-probabilities
 #'
-#'         \item [2] Mean(s): \strong{sample_out$mean}
+#'         \item (2) Mean(s): \strong{sample_out$mean}
 #'
 #'         For univariate data: It is a vector of means. Each element of the vector
 #'         corresponds to one Gaussian.
 #'
-#'         \item [3] Standard-deviation(s): \strong{sample_out$sd}
+#'         \item (3) Standard-deviation(s): \strong{sample_out$sd}
 #'
 #'         For univariate data: Vector of standard deviation for the Gaussian(s))
 #'
-#'         \item [4] Priors: \strong{sample_out$prior}
+#'         \item (4) Priors: \strong{sample_out$prior}
 #'         A vector of priors for the Gaussian(s).
 #'         }
 #'
@@ -66,7 +66,7 @@ require(matrixcalc)
 #'
 #' @references
 #' Hasan Kurban, Mark Jenne, Mehmet M. Dalkilic
-#' (2016) <doi:https://doi.org/10.1007/s41060-017-0062-1>.
+#' (2016) <https://doi.org/10.1007/s41060-017-0062-1>.
 
 dcem_cluster_uv <-
 
@@ -91,32 +91,47 @@ dcem_cluster_uv <-
 
     #Repeat till threshold achieved or convergence whichever is earlier.
     while (counter <= iteration_count) {
+
       old_mean = mean_vector
-      weight_mat = matrix(0,
-                          nrow = num,
-                          ncol = numrows,
-                          byrow = TRUE)
 
       for (clus in 1:num) {
         p_density[clus, ] = dnorm(data, mean_vector[clus] , sd_vector[clus]) * prior_vec[clus]
       }
 
       sum_p_density = colSums(p_density)
+
+      # Commented for testing.
+      # Same operation can be done in a single loop.
+
+      # for (i in 1:num) {
+      #   for (j in 1:numrows){
+      #     weight_mat[i, j] = p_density[i, j] / sum_p_density[j]
+      #   }
+      # }
+
       for (i in 1:num) {
-        for (j in 1:numrows) {
-          weight_mat[i, j] = p_density[i, j] / sum_p_density[j]
-        }
+          p_density[i, ] = p_density[i, ] / sum_p_density
       }
 
-      #Maximize standard-deviation and mean
+      # Maximize standard-deviation and mean
       for (clus in 1:num) {
-        prior_vec[clus] = sum(weight_mat[clus, ]) / numrows
-        mean_vector[clus] = (sum(data * weight_mat[clus, ]) / sum(weight_mat[clus, ]))
-        sd_vector[clus] = sum(((data - mean_vector[clus]) ^ 2) * weight_mat[clus, ])
-        sd_vector[clus] = sqrt(sd_vector[clus] / sum(weight_mat[clus, ]))
+
+        # Don't need an additional weight_mat variable.
+        # Probabilities can be stored in the p_density matrix itself.
+
+        # prior_vec[clus] = sum(weight_mat[clus, ]) / numrows
+        # mean_vector[clus] = (sum(data * weight_mat[clus, ]) / sum(weight_mat[clus, ]))
+        # sd_vector[clus] = sum(((data - mean_vector[clus]) ^ 2) * weight_mat[clus, ])
+        # sd_vector[clus] = sqrt(sd_vector[clus] / sum(weight_mat[clus, ]))
+
+        prior_vec[clus] = sum(p_density[clus, ]) / numrows
+        mean_vector[clus] = (sum(data * p_density[clus, ]) / sum(p_density[clus, ]))
+        sd_vector[clus] = sum(((data - mean_vector[clus]) ^ 2) * p_density[clus, ])
+        sd_vector[clus] = sqrt(sd_vector[clus] / sum(p_density[clus, ]))
+
       }
 
-      #Find the difference in the mean
+      # Find the difference in the mean
       mean_diff = sum((mean_vector - old_mean) ^ 2)
 
       if (!is.na(mean_diff) && mean_diff < threshold) {
@@ -132,12 +147,7 @@ dcem_cluster_uv <-
       counter = counter + 1
     }
 
-    output = list(
-      prob = weight_mat,
-      mean = mean_vector,
-      sd = sd_vector,
-      prior = prior_vec
-    )
+    output = list(prob = p_density, mean = mean_vector, sd = sd_vector, prior = prior_vec)
     return(output)
 
   }
