@@ -21,7 +21,7 @@ source("./R/dcem.R")
 #'
 #' @param num_clusters (numeric): The number of clusters. Default: \strong{2}
 #'
-#' @param seeding (string): The initialisation scheme ('rand', 'improved'). Default: \strong{rand}
+#' @param seeding (string): The initialization scheme ('rand', 'improved'). Default: \strong{rand}
 #'
 #' @return
 #'         A list of objects. This list contains parameters associated with the Gaussian(s)
@@ -30,10 +30,10 @@ source("./R/dcem.R")
 #'         the output:
 #'
 #'\enumerate{
-#'         \item [1] Posterior Probabilities: \strong{sample_out$prob}
+#'         \item (1) Posterior Probabilities: \strong{sample_out$prob}
 #'         A matrix of posterior-probabilities
 #'
-#'         \item [2] Mean(s): \strong{sample_out$mean}
+#'         \item (2) Mean(s): \strong{sample_out$mean}
 #'
 #'         For multivariate data: It is a matrix of means for the Gaussian(s). Each row in
 #'         the  matrix corresponds to a mean for the Gaussian.
@@ -41,7 +41,7 @@ source("./R/dcem.R")
 #'         For univariate data: It is a vector of means. Each element of the vector
 #'         corresponds to one Gaussian.
 #'
-#'         \item [3] Co-variance matrices: \strong{sample_out$cov}
+#'         \item (3) Co-variance matrices: \strong{sample_out$cov}
 #'
 #'         For multivariate data: List of co-variance matrices for the Gaussian(s).
 #'
@@ -49,7 +49,7 @@ source("./R/dcem.R")
 #'
 #'         For univariate data: Vector of standard deviation for the Gaussian(s))
 #'
-#'         \item [4] Priors: \strong{sample_out$prior}
+#'         \item (4) Priors: \strong{sample_out$prior}
 #'         A vector of priors for the Gaussian(s).
 #'         }
 #'
@@ -60,7 +60,7 @@ source("./R/dcem.R")
 #'Using data to build a better EM: EM* for big data.
 #'
 #'Hasan Kurban, Mark Jenne, Mehmet M. Dalkilic
-#'(2016) <doi:https://doi.org/10.1007/s41060-017-0062-1>.
+#'(2016) <https://doi.org/10.1007/s41060-017-0062-1>.
 #'
 #' @examples
 #'# Simulating a mixture of univariate samples from three distributions
@@ -125,14 +125,13 @@ dcem_train <-
 
     if (missing(seeding) ) {
       seeding = "rand"
-      print("Using the random initialisation scheme.")
+      print("Using the random initialization scheme.")
     }
     else{
       seeding = seeding
-      print("Using the improved Kmeans++ initialisation scheme.")
+      print("Using the improved Kmeans++ initialization scheme.")
     }
 
-
     data = as.data.frame(sapply(data, as.numeric))
     data[sapply(data, function(x)
       all(is.na(x)))] <- NULL
